@@ -1,6 +1,6 @@
 """This is where the module comment belongs"""
 
-def print_lol(the_list, indent=False,level=0):
+def print_lol(the_list):
 
 	"""This function returns values from a list and can determine if other lists exixt
 		inside a list and print there contents too. :-)"""
@@ -8,11 +8,10 @@ def print_lol(the_list, indent=False,level=0):
 
 	for each_item in the_list:
 		if isinstance(each_item,list):
-			print_lol(each_item,indent, level+1)
+			print_lol(each_item,level)
 		else:
-			if indent:
-				for num in range(level):
-					print("\t", end='')
+			for num in range(level):
+				print("\t", end='')
 			print (each_item)		
 		
 		
